@@ -12,6 +12,7 @@
 from lakefs_client.model.access_key_credentials import AccessKeyCredentials
 from lakefs_client.model.action_run import ActionRun
 from lakefs_client.model.action_run_list import ActionRunList
+from lakefs_client.model.auth_capabilities import AuthCapabilities
 from lakefs_client.model.authentication_token import AuthenticationToken
 from lakefs_client.model.branch_creation import BranchCreation
 from lakefs_client.model.branch_protection_rule import BranchProtectionRule
@@ -25,6 +26,7 @@ from lakefs_client.model.current_user import CurrentUser
 from lakefs_client.model.diff import Diff
 from lakefs_client.model.diff_list import DiffList
 from lakefs_client.model.error import Error
+from lakefs_client.model.forgot_password_request import ForgotPasswordRequest
 from lakefs_client.model.garbage_collection_prepare_request import GarbageCollectionPrepareRequest
 from lakefs_client.model.garbage_collection_prepare_response import GarbageCollectionPrepareResponse
 from lakefs_client.model.garbage_collection_rule import GarbageCollectionRule
@@ -34,11 +36,15 @@ from lakefs_client.model.group_creation import GroupCreation
 from lakefs_client.model.group_list import GroupList
 from lakefs_client.model.hook_run import HookRun
 from lakefs_client.model.hook_run_list import HookRunList
+from lakefs_client.model.import_pagination import ImportPagination
+from lakefs_client.model.ingest_range_creation_response import IngestRangeCreationResponse
 from lakefs_client.model.inline_object1 import InlineObject1
 from lakefs_client.model.login_information import LoginInformation
 from lakefs_client.model.merge import Merge
 from lakefs_client.model.merge_result import MergeResult
 from lakefs_client.model.merge_result_summary import MergeResultSummary
+from lakefs_client.model.meta_range_creation import MetaRangeCreation
+from lakefs_client.model.meta_range_creation_response import MetaRangeCreationResponse
 from lakefs_client.model.object_error import ObjectError
 from lakefs_client.model.object_error_list import ObjectErrorList
 from lakefs_client.model.object_stage_creation import ObjectStageCreation
@@ -49,6 +55,7 @@ from lakefs_client.model.pagination import Pagination
 from lakefs_client.model.path_list import PathList
 from lakefs_client.model.policy import Policy
 from lakefs_client.model.policy_list import PolicyList
+from lakefs_client.model.range_metadata import RangeMetadata
 from lakefs_client.model.ref import Ref
 from lakefs_client.model.ref_list import RefList
 from lakefs_client.model.refs_dump import RefsDump
@@ -59,6 +66,7 @@ from lakefs_client.model.reset_creation import ResetCreation
 from lakefs_client.model.revert_creation import RevertCreation
 from lakefs_client.model.setup import Setup
 from lakefs_client.model.setup_state import SetupState
+from lakefs_client.model.stage_range_creation import StageRangeCreation
 from lakefs_client.model.staging_location import StagingLocation
 from lakefs_client.model.staging_metadata import StagingMetadata
 from lakefs_client.model.statement import Statement
@@ -66,6 +74,7 @@ from lakefs_client.model.storage_config import StorageConfig
 from lakefs_client.model.storage_uri import StorageURI
 from lakefs_client.model.tag_creation import TagCreation
 from lakefs_client.model.underlying_object_properties import UnderlyingObjectProperties
+from lakefs_client.model.update_password_by_token import UpdatePasswordByToken
 from lakefs_client.model.user import User
 from lakefs_client.model.user_creation import UserCreation
 from lakefs_client.model.user_list import UserList
